==> flutter_mylibrary-0.5.91.tar.gz: lib/config/const.dart <==
import 'package:event_bus/event_bus.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/base/base_view_state.dart';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/win_media.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:logger/logger.dart';
import 'package:synchronized/synchronized.dart';


final EventBus publicEventBus = EventBus();

int startPage = 1;

int pageLimit = 10;

bool centerTitle = true;

double defMargin = 15;

Lock get lock => Lock();

Color primaryColor = Colors.blue;

Logger get logger => Logger(
  printer: PrettyPrinter(),
);

const String defPassword = "@#\$0142365987CDKJDIEWQD@#\$%\^&!!";

const String rsaSplit = "------------$defPassword-------------";

/// **********************************************Widget配置*************************************************************************************/

///loading
Widget get pageLoading => SpinKitWave(color: Theme.of(Get.context).primaryColor, type: SpinKitWaveType.start, size: getSp(24),);

///错误布局
ViewStateWidgetBuilder errorWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);


ViewStateWidgetBuilder emptyWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);

/// **********************************************设置网络错误提示*************************************************************************************/


String HTTP_TIMEOUT_MSG = "网络连接超时，请检查网络设置";
String HTTP_ERROR_MSG = "服务器异常，请稍后重试！";
String CANCEL_MSG = "请求已被取消，请稍后重试！";
String NO_DATA_MSG = '无数据';
String UNAUTHORIZED_MSG = '未允许授权';
String NETWORK_ERROR_MSG = '网络错误';
String SSL_ERROR_MSG = '证书错误';
String UNKNOWN_MSG = '未知错误';
String HTTP_INCORRECT_MSG = '请求错误';
String PARSE_ERROR_MSG = '数据解析错误';

/// **********************************************公用key*************************************************************************************/
const String loginKey = 'loginKey';

const String userKey = 'userKey';

const String themeKey = 'themeKey';

const kThemeUserDarkMode = 'kThemeUserDarkMode';

const kThemeColor = 'kThemeColor';




/// **********************************************自定义方法名*************************************************************************************/
typedef ViewStateModelWidgetBuilder<T> = Widget Function(T value);

typedef ViewStateModelWidgetListBuilder<T> = List<Widget> Function(T value);

typedef ViewStateWidgetBuilder = Widget Function(BaseViewState viewStateModel);

typedef ViewPortBuilder = void Function(int firstIndex, int lastIndex);

typedef ValidateResponse = dynamic Function(dynamic data);

typedef GetxViewStateModelWidgetBuilder<T> = Widget Function(BuildContext context, T model);

typedef DioWidgetBuilder = Widget Function(HttpData httpData);

==> flutter_mylibrary-0.6.1.tar.gz: lib/config/const.dart <==
import 'package:event_bus/event_bus.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/base/base_view_state.dart';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/win_media.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:logger/logger.dart';


final EventBus publicEventBus = EventBus();

int startPage = 1;

int pageLimit = 10;

bool centerTitle = true;

double defMargin = 15;

// Lock get lock => Lock();

Color primaryColor = Colors.blue;

BuildContext context = Get.context;

double toolBarHeight = kToolbarHeight;

Logger get logger => Logger(
  printer: PrettyPrinter(),
);

const String defPassword = "@#\$0142365987CDKJDIEWQD@#\$%\^&!!";

const String rsaSplit = "------------$defPassword-------------";

/// **********************************************Widget配置*************************************************************************************/

///loading
Widget get pageLoading => SpinKitWave(color: Theme.of(Get.context).primaryColor, type: SpinKitWaveType.start, size: getSp(24),);

///错误布局
ViewStateWidgetBuilder errorWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);


ViewStateWidgetBuilder emptyWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);

/// **********************************************设置网络错误提示*************************************************************************************/


String HTTP_TIMEOUT_MSG = "网络连接超时，请检查网络设置";
String HTTP_ERROR_MSG = "服务器异常，请稍后重试！";
String CANCEL_MSG = "请求已被取消，请稍后重试！";
String NO_DATA_MSG = '无数据';
String UNAUTHORIZED_MSG = '未允许授权';
String NETWORK_ERROR_MSG = '网络错误';
String SSL_ERROR_MSG = '证书错误';
String UNKNOWN_MSG = '未知错误';
String HTTP_INCORRECT_MSG = '请求错误';
String PARSE_ERROR_MSG = '数据解析错误';

/// **********************************************公用key*************************************************************************************/
const String loginKey = 'loginKey';

const String userKey = 'userKey';

const String themeKey = 'themeKey';

const kThemeUserDarkMode = 'kThemeUserDarkMode';

const kThemeColor = 'kThemeColor';




/// **********************************************自定义方法名*************************************************************************************/
typedef ViewStateModelWidgetBuilder<T> = Widget Function(T value);

typedef ViewStateModelWidgetListBuilder<T> = List<Widget> Function(T value);

typedef ViewStateWidgetBuilder = Widget Function(BaseViewState viewStateModel);

typedef ViewPortBuilder = void Function(int firstIndex, int lastIndex);

typedef ValidateResponse = dynamic Function(dynamic data);

typedef GetxViewStateModelWidgetBuilder<T> = Widget Function(BuildContext context, T model);

typedef DioWidgetBuilder = Widget Function(HttpData httpData);
